==> tty-grin-0.4.7.tar.gz: tty-grin-0.4.7/lisp/integer.h <==
// -*-Mode: C++;-*-

// Grin LISP
// Copyright (C) 2001 Daniel Beer
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

namespace lisp {
  class integer : public number {
  public:
    integer(int v) : number(INTEGER, "INTEGER"), value(v) { }

    int get_value(void) const { return value; }
    void set_value(int x) { value=x; }

    virtual string print(void) const;
    virtual bool equal(object) const;
    virtual object convert(enum contagion_level) const;
    virtual object unary(enum unary_op) const;
    virtual object binary(enum binary_op, object) const;

  private:
    int value;
  };

  inline bool is_integer(const object x) {
    return dynamic_cast<const integer *>(x.get_const_data())!=0;
  }

  inline integer& assume_integer(object x) {
    return *(integer *)x.get_data();
  }

  inline integer& as_integer(object x) {
    integer *i=dynamic_cast<integer *>(x.get_data());
    if(i) return *i;
    throw error(x, _("Type mismatch"));
  }
};

==> tty-grin-0.4.8.tar.gz: tty-grin-0.4.8/lisp/integer.h <==
// -*-Mode: C++;-*-

// Grin LISP
// Copyright (C) 2001 Daniel Beer
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

namespace lisp {
  class integer : public number {
  public:
    integer(int v) : number(INTEGER), value(v) { }

    int get_value(void) const { return value; }
    void set_value(int x) { value=x; }

    virtual string print(void) const;
    virtual bool equal(object) const;
    virtual object convert(enum contagion_level) const;
    virtual object unary(enum unary_op) const;
    virtual object binary(enum binary_op, object) const;
    virtual const char *get_typeof(void) const;

  private:
    int value;
  };

  inline bool is_integer(const object x) {
    return dynamic_cast<const integer *>(x.get_const_data())!=0;
  }

  inline integer& assume_integer(object x) {
    return *(integer *)x.get_data();
  }

  inline integer& as_integer(object x) {
    integer *i=dynamic_cast<integer *>(x.get_data());
    if(i) return *i;
    throw error(x, _("Type mismatch"));
  }
};
